<input type="hidden" class="iterable_name" name="destination_tp_{{loop.index}}" value="powerpoint">
<div class="field">
    <div class="fields">
        <div class="field" style="width: 65%;">
            <label>Presentation Path</label>
            <input type="text" class="iterable_name" name="destination_presentation_path_{{loop.index}}" placeholder="C://" value="{{connection.destination.presentation_path}}">
        </div>
        <div class="field" style="width: 20%;">
            <label>Slide Index</label>
            <input type="text" class="iterable_name" name="destination_slide_index_{{loop.index}}" placeholder="Int" value="{{connection.destination.slide_index}}">
        </div>
        <div class="field" style="width: 15%;">
            <label>Slide ID</label>
            <input type="text" class="iterable_name" name="destination_slide_id_{{loop.index}}" placeholder="" value="{{connection.destination.slide_id}}">
        </div>
        <div class="ui button iterable_id" style="width:10px; margin-top:24px;" id="destination_presentation_path_button_{{loop.index}}" onclick="file_button(this.id)">
            <i class="file outline icon" style="padding-right:17px;"></i>
        </div>
    </div>
</div>
<div class="field">
    <div class="four fields">
        <div class="field">
            <label>Width</label>
            <input type="number" step="0.01" class="iterable_name" name="destination_w_{{loop.index}}" placeholder="W" value="{{connection.destination.w}}">
        </div>
        <div class="field">
            <label>Height</label>
            <input type="number" step="0.01" class="iterable_name" name="destination_h_{{loop.index}}" placeholder="H" value="{{connection.destination.h}}">
        </div>
        <div class="field">
            <label>X-Axis</label>
            <input type="number" step="0.01" class="iterable_name" name="destination_x_{{loop.index}}" placeholder="X" value="{{connection.destination.x}}">
        </div>
        <div class="field">
            <label>Y-Axis</label>
            <input type="number" step="0.01" class="iterable_name" name="destination_y_{{loop.index}}" placeholder="Y" value="{{connection.destination.y}}">
        </div>
        <div class="field" style="margin-top:25px;">
            <div class="ui checkbox">
                <input type="checkbox" id="destination_resize_{{loop.index}}" class="iterable_id">
                <input type="hidden" name="destination_resize_{{loop.index}}" value="{{connection.destination.resize}}" class="checkbox_helper iterable_name">
                <label>Resize Image</label>
            </div>
        </div>
    </div>
</div>