SOURCES = {
    "fields" : {
        "excel" : ["sheet", "rng", "excel_path"], 
        "sheets" : ["sheet", "rng", "sheet_id"]
    }
}
DESTINATIONS = {
    "fields" : {
        "slides" : ["w", "h", "x", "y", "presentation_id", "page_id"], 
        "powerpoint" : ["w", "h", "x", "y","presentation_path", "slide_index", "slide_id"]
    }
}