import os

CONNECTIONS_PATH="data.json"
GOOGLE_PICKER_KEY="AIzaSyDNRPFphQ7TxAqm7IgLp_C8wrFQCYCTjww"
GOOGLE_SCOPES=["https://www.googleapis.com/auth/drive", "https://www.googleapis.com/auth/presentations"]
GOOGLE_REDIRECT="http://localhost:5500/callback"
GOOGLE_CREDS_PATH="creds/credentials.json"
GOOGLE_TOKEN_PATH="creds/token.pickle"
GOOGLE_TOKEN_JSON="creds/token.json"
PROJECT_NAME="stoffel"

